==> plplot_5.10.0.orig.tar.gz: plplot-5.10.0/doc/doxygen/html/metadefs_8h.js <==
var metadefs_8h =
[
    [ "ADVANCE", "metadefs_8h.html#ad4425e8f14c95d8eef966542aa90763b", null ],
    [ "BOP", "metadefs_8h.html#a857adfef718262ca4a28b3648c56de5c", null ],
    [ "BOP0", "metadefs_8h.html#a7602e5c62ddc385d9df6c96b898f889f", null ],
    [ "CHANGE_STATE", "metadefs_8h.html#ac8a92314853800ead4359d8572aeaafe", null ],
    [ "CLOSE", "metadefs_8h.html#a0e29f488071372aa0530842e60b64511", null ],
    [ "END_OF_FIELD", "metadefs_8h.html#a3394e2c0c098b2ba3a1ec924b7ab5826", null ],
    [ "EOP", "metadefs_8h.html#a734579b908509b57151ac02b946056d1", null ],
    [ "ESCAPE", "metadefs_8h.html#afe4b0e625372cd38ec60150d6f5594b8", null ],
    [ "INITIALIZE", "metadefs_8h.html#a54d9d5275789304c07d2d9a570a0b439", null ],
    [ "LINE", "metadefs_8h.html#af94cfb03461685fead1fe045d5c96f01", null ],
    [ "LINETO", "metadefs_8h.html#a2feb78f58cdc6ede886c84a21404f9e0", null ],
    [ "NEW_COLOR", "metadefs_8h.html#a8c5d54a1c71b2e3ddc9f813dc719a42b", null ],
    [ "NEW_COLOR0", "metadefs_8h.html#ab1134456aff4108770f9f42271508de7", null ],
    [ "NEW_COLOR1", "metadefs_8h.html#acecd3b961543f9b3555b13fdd97e6573", null ],
    [ "NEW_WIDTH", "metadefs_8h.html#a09fd9a1c0320430272c9ee1b21fb4b15", null ],
    [ "PIXEL_RES_X_OLD", "metadefs_8h.html#a96730d05ad2a07a4b19fe154f24137f2", null ],
    [ "PIXEL_RES_Y_OLD", "metadefs_8h.html#aa982f9019bc39bba612f10b4363a7814", null ],
    [ "plm_rd", "metadefs_8h.html#ab3a6bd5ed1cbaae1db778d76abfbfed8", null ],
    [ "plm_wr", "metadefs_8h.html#a37389f4fb994c03c2206bd4103a8c16f", null ],
    [ "PLMETA_HEADER", "metadefs_8h.html#a3bb571c4f11f5f5cb152e6e9433ad770", null ],
    [ "PLMETA_VERSION", "metadefs_8h.html#aa77188678f3303c33c7fae0656fd21aa", null ],
    [ "PLMETA_X_OLD", "metadefs_8h.html#ac44208d4bf130212246788c731b99856", null ],
    [ "PLMETA_Y_OLD", "metadefs_8h.html#ad1e3938b8d650bd072c3d32a88269406", null ],
    [ "PLSERV_HEADER", "metadefs_8h.html#a13e85a1ed167ab43dc64bb8a96c08d54", null ],
    [ "PLSERV_VERSION", "metadefs_8h.html#ae2a6432d568327d448b7135847092a2b", null ],
    [ "POLYLINE", "metadefs_8h.html#ae38b6e405395fa5184aaccb260ccb135", null ],
    [ "SWITCH_TO_GRAPH", "metadefs_8h.html#ac4382ab45a4cecf92033fac1f49c06e3", null ],
    [ "SWITCH_TO_TEXT", "metadefs_8h.html#aaa8308d7392d97bc8f8a6efd6ff90466", null ]
];

==> plplot-5.15.0.tar.gz: plplot-5.15.0/doc/doxygen/html/metadefs_8h.js <==
var metadefs_8h =
[
    [ "PLmIndex", "structPLmIndex.html", "structPLmIndex" ],
    [ "PLmDev", "structPLmDev.html", "structPLmDev" ],
    [ "ADVANCE", "metadefs_8h.html#ad4425e8f14c95d8eef966542aa90763b", null ],
    [ "BOP", "metadefs_8h.html#a857adfef718262ca4a28b3648c56de5c", null ],
    [ "BOP0", "metadefs_8h.html#a7602e5c62ddc385d9df6c96b898f889f", null ],
    [ "CHANGE_STATE", "metadefs_8h.html#ac8a92314853800ead4359d8572aeaafe", null ],
    [ "CLIP", "metadefs_8h.html#aeb447a7da70893212e1e61e6086c6e80", null ],
    [ "CLOSE", "metadefs_8h.html#a0e29f488071372aa0530842e60b64511", null ],
    [ "DRIVER_INTERFACE", "metadefs_8h.html#a69063a66eb5cc1673e7898be53e40bd5", null ],
    [ "END_OF_FIELD", "metadefs_8h.html#a3394e2c0c098b2ba3a1ec924b7ab5826", null ],
    [ "EOP", "metadefs_8h.html#a734579b908509b57151ac02b946056d1", null ],
    [ "ESCAPE", "metadefs_8h.html#afe4b0e625372cd38ec60150d6f5594b8", null ],
    [ "INITIALIZE", "metadefs_8h.html#a54d9d5275789304c07d2d9a570a0b439", null ],
    [ "LINE", "metadefs_8h.html#af94cfb03461685fead1fe045d5c96f01", null ],
    [ "LINETO", "metadefs_8h.html#a2feb78f58cdc6ede886c84a21404f9e0", null ],
    [ "NEW_COLOR", "metadefs_8h.html#a8c5d54a1c71b2e3ddc9f813dc719a42b", null ],
    [ "NEW_COLOR0", "metadefs_8h.html#ab1134456aff4108770f9f42271508de7", null ],
    [ "NEW_COLOR1", "metadefs_8h.html#acecd3b961543f9b3555b13fdd97e6573", null ],
    [ "NEW_WIDTH", "metadefs_8h.html#a09fd9a1c0320430272c9ee1b21fb4b15", null ],
    [ "PIXEL_RES_X_OLD", "metadefs_8h.html#a96730d05ad2a07a4b19fe154f24137f2", null ],
    [ "PIXEL_RES_Y_OLD", "metadefs_8h.html#aa982f9019bc39bba612f10b4363a7814", null ],
    [ "plm_rd", "metadefs_8h.html#ab3a6bd5ed1cbaae1db778d76abfbfed8", null ],
    [ "plm_wr", "metadefs_8h.html#a37389f4fb994c03c2206bd4103a8c16f", null ],
    [ "PLMETA_HEADER", "metadefs_8h.html#a3bb571c4f11f5f5cb152e6e9433ad770", null ],
    [ "PLMETA_VERSION", "metadefs_8h.html#aa77188678f3303c33c7fae0656fd21aa", null ],
    [ "PLMETA_X_OLD", "metadefs_8h.html#ac44208d4bf130212246788c731b99856", null ],
    [ "PLMETA_Y_OLD", "metadefs_8h.html#ad1e3938b8d650bd072c3d32a88269406", null ],
    [ "PLSERV_HEADER", "metadefs_8h.html#a13e85a1ed167ab43dc64bb8a96c08d54", null ],
    [ "PLSERV_VERSION", "metadefs_8h.html#ae2a6432d568327d448b7135847092a2b", null ],
    [ "POLYLINE", "metadefs_8h.html#ae38b6e405395fa5184aaccb260ccb135", null ],
    [ "SETSUB", "metadefs_8h.html#a5b0117b6132f309a8d5c393433acd3cc", null ],
    [ "SSUB", "metadefs_8h.html#ace6b57f62d946947c2de4e67f75fc9bf", null ],
    [ "SWITCH_TO_GRAPH", "metadefs_8h.html#ac4382ab45a4cecf92033fac1f49c06e3", null ],
    [ "SWITCH_TO_TEXT", "metadefs_8h.html#aaa8308d7392d97bc8f8a6efd6ff90466", null ]
];
